@@ -1,7 +1,7 @@
 package Config::IOD::Document;
 
-our $DATE = '2016-03-01'; # DATE
-our $VERSION = '0.27'; # VERSION
+our $DATE = '2016-03-02'; # DATE
+our $VERSION = '0.28'; # VERSION
 
 use 5.010;
 use strict;
@@ -708,6 +708,34 @@ sub delete_key {
     $num_deleted;
 }
 
+sub set_value {
+    my $self = shift;
+    my $opts;
+    if (ref($_[0]) eq 'HASH') {
+        $opts = shift;
+    } else {
+        $opts = {};
+    }
+
+    my $section = $_[0];
+    my $key     = $_[1];
+    my ($err_value, $value) = $self->_validate_value($_[2]);
+    die $err_value if $err_value;
+
+    my $found;
+    $self->each_key(
+        sub {
+            my ($self, %args) = @_;
+            return if $found && !$opts->{all};
+            return unless $args{section} eq $section;
+            return unless $args{key} eq $key;
+            $found++;
+            my $l = $self->{_parsed}[ $args{linum}-1 ];
+            $l->[COL_K_VALUE_RAW] = $value;
+        },
+    );
+}
+
 sub as_string {
     my $self = shift;
 
@@ -786,7 +814,7 @@ Config::IOD::Document - Represent IOD document
 
 =head1 VERSION
 
-This document describes version 0.27 of Config::IOD::Document (from Perl distribution Config-IOD), released on 2016-03-01.
+This document describes version 0.28 of Config::IOD::Document (from Perl distribution Config-IOD), released on 2016-03-02.
 
 =head1 SYNOPSIS
 
@@ -1105,13 +1133,25 @@ If set to 1, will only list the first occurrence of each key.
 
 =back
 
+=head2 $doc->set_value([ \%opts ], $section, $key, $new_value)
+
+Set value of a key.
+
+Options:
+
+=over
+
+=item * all => bool
+
+=back
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Config-IOD>.
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Config-IOD>.
+Source repository is at L<https://github.com/sharyanto/perl-Config-IOD>.
 
 =head1 BUGS
 
